/****************************************************************************
** Meta object code from reading C++ file 'qlowenergycontroller_bluez_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/bluetooth/qlowenergycontroller_bluez_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qlowenergycontroller_bluez_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QLowEnergyControllerPrivateBluez_t {
    QByteArrayData data[11];
    char stringdata0[224];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QLowEnergyControllerPrivateBluez_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QLowEnergyControllerPrivateBluez_t qt_meta_stringdata_QLowEnergyControllerPrivateBluez = {
    {
QT_MOC_LITERAL(0, 0, 32), // "QLowEnergyControllerPrivateBluez"
QT_MOC_LITERAL(1, 33, 13), // "l2cpConnected"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 16), // "l2cpDisconnected"
QT_MOC_LITERAL(4, 65, 16), // "l2cpErrorChanged"
QT_MOC_LITERAL(5, 82, 29), // "QBluetoothSocket::SocketError"
QT_MOC_LITERAL(6, 112, 13), // "l2cpReadyRead"
QT_MOC_LITERAL(7, 126, 22), // "encryptionChangedEvent"
QT_MOC_LITERAL(8, 149, 17), // "QBluetoothAddress"
QT_MOC_LITERAL(9, 167, 24), // "handleGattRequestTimeout"
QT_MOC_LITERAL(10, 192, 31) // "activeConnectionTerminationDone"

    },
    "QLowEnergyControllerPrivateBluez\0"
    "l2cpConnected\0\0l2cpDisconnected\0"
    "l2cpErrorChanged\0QBluetoothSocket::SocketError\0"
    "l2cpReadyRead\0encryptionChangedEvent\0"
    "QBluetoothAddress\0handleGattRequestTimeout\0"
    "activeConnectionTerminationDone"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QLowEnergyControllerPrivateBluez[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x08 /* Private */,
       3,    0,   50,    2, 0x08 /* Private */,
       4,    1,   51,    2, 0x08 /* Private */,
       6,    0,   54,    2, 0x08 /* Private */,
       7,    2,   55,    2, 0x08 /* Private */,
       9,    0,   60,    2, 0x08 /* Private */,
      10,    0,   61,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Bool,    2,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void QLowEnergyControllerPrivateBluez::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QLowEnergyControllerPrivateBluez *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->l2cpConnected(); break;
        case 1: _t->l2cpDisconnected(); break;
        case 2: _t->l2cpErrorChanged((*reinterpret_cast< QBluetoothSocket::SocketError(*)>(_a[1]))); break;
        case 3: _t->l2cpReadyRead(); break;
        case 4: _t->encryptionChangedEvent((*reinterpret_cast< const QBluetoothAddress(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 5: _t->handleGattRequestTimeout(); break;
        case 6: _t->activeConnectionTerminationDone(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QBluetoothAddress >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QLowEnergyControllerPrivateBluez::staticMetaObject = { {
    QMetaObject::SuperData::link<QLowEnergyControllerPrivate::staticMetaObject>(),
    qt_meta_stringdata_QLowEnergyControllerPrivateBluez.data,
    qt_meta_data_QLowEnergyControllerPrivateBluez,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QLowEnergyControllerPrivateBluez::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QLowEnergyControllerPrivateBluez::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QLowEnergyControllerPrivateBluez.stringdata0))
        return static_cast<void*>(this);
    return QLowEnergyControllerPrivate::qt_metacast(_clname);
}

int QLowEnergyControllerPrivateBluez::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLowEnergyControllerPrivate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
